@@ -3,7 +3,7 @@
 #
 # Univention Common Python Library
 #
-# Copyright 2014-2021 Univention GmbH
+# Copyright 2014-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -47,7 +47,7 @@ import ipaddress
 import time
 from datetime import datetime, timedelta
 import pipes
-from typing import Optional  # noqa F401
+from typing import Optional  # noqa: F401
 
 import six
 
