@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
-# Copyright 2012-2021 Univention GmbH
+# Copyright 2012-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -41,7 +41,7 @@ import datetime
 import subprocess
 import re
 import locale
-from typing import Dict, List, Mapping, Optional, Union  # noqa F401
+from typing import Dict, List, Mapping, Optional, Union  # noqa: F401
 
 __all__ = ['add', 'list', 'load', 'remove', 'reschedule', 'AtJob']
 
