@@ -3,7 +3,7 @@
 """
 Internationalization (i18n) utilities.
 """
-# Copyright 2006-2021 Univention GmbH
+# Copyright 2006-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -33,7 +33,7 @@ Internationalization (i18n) utilities.
 import gettext
 from locale import getlocale, Error, LC_MESSAGES
 import re
-from typing import Optional, Text  # noqa F401
+from typing import Optional, Text  # noqa: F401
 
 import six
 
