@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
-# Copyright 2015-2021 Univention GmbH
+# Copyright 2015-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -33,7 +33,7 @@ from __future__ import print_function
 import sys
 import datetime
 from argparse import ArgumentParser, RawDescriptionHelpFormatter
-from typing import Optional  # noqa F401
+from typing import Optional  # noqa: F401
 
 import univention.uldap
 
