@@ -2,7 +2,7 @@
 """
 Univention Common Python Library for file locking
 """
-# Copyright 2011-2021 Univention GmbH
+# Copyright 2011-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -33,7 +33,7 @@ from __future__ import print_function
 
 import fcntl
 import os
-from typing import IO, Optional, Text  # noqa F401
+from typing import IO, Optional, Text  # noqa: F401
 
 
 def get_lock(name, nonblocking=False):
