@@ -3,7 +3,7 @@
 """
 Univention Common Python Library
 """
-# Copyright 2012-2021 Univention GmbH
+# Copyright 2012-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -31,7 +31,7 @@ Univention Common Python Library
 # <https://www.gnu.org/licenses/>.
 
 import subprocess
-from typing import Optional  # noqa F401
+from typing import Optional  # noqa: F401
 
 from univention.config_registry import ConfigRegistry
 
