@@ -3,7 +3,7 @@
 """
 Univention common Python library for :command:`logrotate` configuration files.
 """
-# Copyright 2010-2021 Univention GmbH
+# Copyright 2010-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -30,9 +30,9 @@ Univention common Python library for :command:`logrotate` configuration files.
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from typing import Dict  # noqa F401
+from typing import Dict  # noqa: F401
 
-from univention.config_registry import ConfigRegistry  # noqa F401
+from univention.config_registry import ConfigRegistry  # noqa: F401
 
 
 def _getBoolDefault(varGlobal, varLocal, settings, configRegistry):
