@@ -4,7 +4,7 @@
 Univention common Python library with
 helper functions for MIME type handling.
 """
-# Copyright 2013-2021 Univention GmbH
+# Copyright 2013-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -36,7 +36,7 @@ import zlib
 from PIL import Image
 import io
 import magic
-from typing import Any, Callable, Optional, Tuple  # noqa F401
+from typing import Any, Callable, Optional, Tuple  # noqa: F401
 
 MIME_TYPE = magic.open(magic.MAGIC_MIME_TYPE)
 MIME_TYPE.load()
