@@ -1,7 +1,7 @@
 # shellcheck shell=bash
 # Univention Common Shell Library
 #
-# Copyright 2011-2021 Univention GmbH
+# Copyright 2011-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -183,4 +183,11 @@ custom_groupname() {
 	echo -n "${result:-$name}"
 }
 
+#
+# Echo with timestamp
+#
+echowithtimestamp() {
+	echo "[$(date '+%F %T.%N')] $@"
+}
+
 # vim:set sw=4 ts=4 noet:
