@@ -4,7 +4,7 @@
 # Univention Lib
 #  shell function for creating UMC operation and acl objects
 #
-# Copyright 2011-2021 Univention GmbH
+# Copyright 2011-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -67,7 +67,10 @@ umc_frontend_new_hash () {
 	if [ -n "$DPKG_MAINTSCRIPT_PACKAGE" ]; then
 		# touch all html, js, css files from the package to prevent the mtime to be the package build time.
 		# the mtime needs to be the package extraction time, so that apache serves correct caching information
-		find $(dpkg -L "$DPKG_MAINTSCRIPT_PACKAGE" | grep '^/') -maxdepth 0 -mindepth 0 -type f \( -name '*.js' -or -name '*.html' -or -name '*.css' \) -exec touch {} \;
+		dpkg -L "$DPKG_MAINTSCRIPT_PACKAGE" | grep '^/' | while IFS='' read -r line
+		do
+			find "$line" -maxdepth 0 -mindepth 0 -type f \( -name '*.js' -or -name '*.html' -or -name '*.css' \) -exec touch '{}' \;
+		done
 	fi
 
 	/usr/sbin/univention-config-registry set "umc/web/cache_bust=$(date +%s)"
